.. currentmodule:: hydromt_wflow

=========
Workflows
=========
API documentation of model specific workflows.

Glaciers
========

.. autosummary::
   :toctree: ../generated/

   workflows.glaciers.glaciermaps
   workflows.glaciers.glacierattrs

River
=====

.. autosummary::
   :toctree: ../generated/

   workflows.river.river
   workflows.river.river_width

Soilgrids
=========

.. autosummary::
   :toctree: ../generated/

   workflows.soilgrids.soilgrids
   workflows.soilgrids.soilgrids_sediment

Waterbodies
===========

.. autosummary::
   :toctree: ../generated/

   workflows.waterbodies.waterbodymaps
   workflows.waterbodies.reservoirattrs